==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var ChaikinVolatilityIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChaikinVolatilityIndicator, _super);
    function ChaikinVolatilityIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinVolatilityIndicator.prototype.get_ul = function () {
        return new ChaikinVolatilityIndicatorStrategy();
    };
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    ChaikinVolatilityIndicator.prototype.get_uy = function () {
        return ChaikinVolatilityIndicator.$;
    };
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "u6", {
        get: function () {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.u7));
        },
        set: function (a) {
            this.h(ChaikinVolatilityIndicator.u7, a);
        },
        enumerable: false,
        configurable: true
    });
    ChaikinVolatilityIndicator.prototype.ur = function () {
        return this.u6;
    };
    ChaikinVolatilityIndicator.prototype.u0 = function (a) {
        this.u6 = a;
    };
    ChaikinVolatilityIndicator.$t = markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.u7 = StrategyBasedIndicator.u3(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
}(StrategyBasedIndicator));
export { ChaikinVolatilityIndicator };

==> igniteui-react-charts-18.5.1.tgz: package/esm5/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var ChaikinVolatilityIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChaikinVolatilityIndicator, _super);
    function ChaikinVolatilityIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinVolatilityIndicator.prototype.bg = function () {
        return new ChaikinVolatilityIndicator();
    };
    ChaikinVolatilityIndicator.prototype.get_yz = function () {
        return new ChaikinVolatilityIndicatorStrategy();
    };
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    ChaikinVolatilityIndicator.prototype.get_zc = function () {
        return ChaikinVolatilityIndicator.$;
    };
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "zk", {
        get: function () {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.zl));
        },
        set: function (a) {
            this.h(ChaikinVolatilityIndicator.zl, a);
        },
        enumerable: false,
        configurable: true
    });
    ChaikinVolatilityIndicator.prototype.y5 = function () {
        return this.zk;
    };
    ChaikinVolatilityIndicator.prototype.ze = function (a) {
        this.zk = a;
    };
    ChaikinVolatilityIndicator.$t = markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.zl = StrategyBasedIndicator.zh(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
}(StrategyBasedIndicator));
export { ChaikinVolatilityIndicator };
